==> filemv0.372.0.2.zip: source/dir.h <==
#ifndef _dirw
#define _dirw

#include <stdio.h>

class dirw
{
	int tab;
	char dir[1000];
	char drive[1000];
    ULARGE_INTEGER FreeBytesAv;
    ULARGE_INTEGER Bytes;
    ULARGE_INTEGER FreeBytes;
    DWORD SectorsPerCluster;
    DWORD BytesPerSector;
    DWORD NumberOfFreeClusters;
    DWORD TotalNumberOfClusters;
	char file[1000];
	HWND hList;
	HWND hEdit;
	DWORD itemnum;
	double space;
	double total;
	HIMAGELIST hImage;
public:
	dirw(){wsprintf(dir,".");};
	dirw(int t){wsprintf(dir,"."); setTab(t);};
	void setTab(int t) {tab =t;};
	void setList(HWND li) {hList = li;};
	void setEdit(HWND ed) {hEdit = ed;};
	void resetEditText() { SetWindowText(hEdit, dir); };
	DWORD GetItemNum() {return itemnum;};
	double GetTotal() {return total;};
	double GetSpace() {return space;};
	void SetItemNum(DWORD n) {itemnum =n;};
	void SetSpace(DWORD sp) {space =sp;};
	void setImage(HIMAGELIST im) {hImage = im;};
	HWND getEdit() {return hEdit;};
	HWND getList() {return hList;};
	HIMAGELIST getImage() {return hImage;};
	void SetHandle(HWND li, HWND ed, HIMAGELIST im) {setEdit(ed); setList(li); setImage(im); }
	char *cd(char *d) {this->SetCurrentDirectory(d); return dir; };
	char *SetCurrentDirectory(char *d)
	{
		//
		BOOL f=FALSE;
		if(strcmp(dir,d)==0 && strlen(d)>0) f=TRUE;
		::SetCurrentDirectory(dir);
		::SetCurrentDirectory(d);
		::GetCurrentDirectory(1000,dir);
		sprintf(drive,"%s",dir);
		if(!f && strlen(d)>0) savedir();
		char *p =strchr( drive,'\\' );
		if (p !=NULL ) if(strlen(p) >1 ) p[1]=0;
		int i=GetDiskFreeSpaceEx( drive, &FreeBytesAv,
			&Bytes,
			&FreeBytes);
	//	(double)FreeAvBytes.u.HighPart*4294967296.0 + (double)FreeAvBytes.u.LowPart
		if(i) 
		{
			space =((double)(FreeBytesAv.u.LowPart)+
				(double)FreeBytesAv.u.HighPart*4294967296.0)/1024/1024;
			total =((double)(Bytes.u.LowPart)+
				(double)Bytes.u.HighPart*4294967296.0)/1024/1024;
		}
		//space =(double)NumberOfFreeClusters *SectorsPerCluster *BytesPerSector/1024/1024;
		else {space =0;total =0;};
		return dir;
	};
	void setfile(char *f) {wsprintf(file,"%s",f);};
	char *getfile() {return file;};
	char *cd() {return GetCurrentDirectory(0,NULL);};
	char *GetCurrentDirectory(DWORD l,char *d){if(d!=NULL)wsprintf(d,"%s",dir); return dir;};
	void savedir();
	void hisback();
	void hispos(int i);
	void cdroot() {cd(drive);};
};

void Exchange(dirw&, dirw&);

#endif

==> filemv0.378.1.zip: source/dir.h <==
#ifndef _dirw
#define _dirw

#include <stdio.h>


class dirw
{
	int tab;
	char dir[1000];
	char *clipname;
	char drive[1000];
	int clipmax;
    ULARGE_INTEGER FreeBytesAv;
    ULARGE_INTEGER Bytes;
    ULARGE_INTEGER FreeBytes;
    DWORD SectorsPerCluster;
    DWORD BytesPerSector;
    DWORD NumberOfFreeClusters;
    DWORD TotalNumberOfClusters;
	char file[1000];
	HWND hList;
	HWND hEdit;
	DWORD itemnum;
	double space;
	double total;
	HIMAGELIST hImage;
public:
	dirw(){wsprintf(dir,"."); clipname =dir+5;};
	dirw(int t){wsprintf(dir,"."); setTab(t); clipname =dir+5;};
	BOOL isclip() ;
	char *getClipName() {return clipname;} ;
	int getClipMax() ;
	void setTab(int t) {tab =t;};
	void setList(HWND li) {hList = li;};
	void setEdit(HWND ed) {hEdit = ed;};
	void resetEditText() { SetWindowText(hEdit, dir); };
	DWORD GetItemNum() {return itemnum;};
	double GetTotal() {return total;};
	double GetSpace() {return space;};
	void SetItemNum(DWORD n) {itemnum =n;};
	void SetSpace(DWORD sp) {space =sp;};
	void setImage(HIMAGELIST im) {hImage = im;};
	HWND getEdit() {return hEdit;};
	HWND getList() {return hList;};
	HIMAGELIST getImage() {return hImage;};
	void SetHandle(HWND li, HWND ed, HIMAGELIST im) {setEdit(ed); setList(li); setImage(im); }
	char *cd(char *d) {this->SetCurrentDirectory(d); return dir; };
	char *SetCurrentDirectory(char *d);
	void setfile(char *f) {wsprintf(file,"%s",f);};
	char *getfile() {return file;};
	char *cd() {return GetCurrentDirectory(0,NULL);};
	char *GetCurrentDirectory(DWORD l,char *d){if(d!=NULL)wsprintf(d,"%s",dir); return dir;};
	void savedir();
	void hisback();
	void hispos(int i);
	void cdroot() {cd(drive);};
	char *getClip(int);
};

#define _CLIP "clip:"
#define _ClipLen 5

void Exchange(dirw&, dirw&);
BOOL isclip(char *d);
BOOL addclip(char *,char *to);

#endif
